# Test

Hans Petter Langtangen [1] (`hpl at simula.no`)
Kaare Dump [2] (`kd at simula.no`)
Joe Doe

[1] Simula
[2] UiO

#### Jan 32, 1999

# Table of contents

My first chapter
A section
Basic Theory
Exercise 1: My problem

# My first chapter

$$ a = b $$

# A section

Write text.

# Basic Theory

A first discovery was that 1+1 is 2.

## Exercise 1: My problem

Here is an important equation:

$$ \begin{equation} 2+2 = 4 \label{my:prob:eq1} \end{equation} $$

As shown in \eqref{my:prob:eq1}, 2 and 2 is 4.

© 2021, Hans Petter Langtangen, Simula, Kaare Dump. Made with DocOnce